@@ -1,6 +1,6 @@
 package Log::Dispatch;
 {
-  $Log::Dispatch::VERSION = '2.32';
+  $Log::Dispatch::VERSION = '2.41';
 }
 
 use 5.006;
@@ -231,7 +231,10 @@ sub output {
 
 sub level_is_valid {
     shift;
-    return $LEVELS{ shift() };
+    my $level = shift
+        or Carp::croak('Logging level was not provided');
+
+    return $LEVELS{$level};
 }
 
 sub would_log {
@@ -264,7 +267,7 @@ sub is_emergency { $_[0]->would_log('emergency') }
 
 # ABSTRACT: Dispatches messages to one or more outputs
 
-
+__END__
 
 =pod
 
@@ -274,7 +277,7 @@ Log::Dispatch - Dispatches messages to one or more outputs
 
 =head1 VERSION
 
-version 2.32
+version 2.41
 
 =head1 SYNOPSIS
 
@@ -684,14 +687,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2013 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
