@@ -1,6 +1,6 @@
 package Log::Dispatch::Base;
 {
-  $Log::Dispatch::Base::VERSION = '2.32';
+  $Log::Dispatch::Base::VERSION = '2.41';
 }
 
 use strict;
@@ -13,10 +13,10 @@ sub _get_callbacks {
     return unless exists $p{callbacks};
 
     return @{ $p{callbacks} }
-        if UNIVERSAL::isa( $p{callbacks}, 'ARRAY' );
+        if ref $p{callbacks} eq 'ARRAY';
 
     return $p{callbacks}
-        if UNIVERSAL::isa( $p{callbacks}, 'CODE' );
+        if ref $p{callbacks} eq 'CODE';
 
     return;
 }
@@ -50,7 +50,7 @@ sub add_callback {
 
 # ABSTRACT: Code shared by dispatch and output objects.
 
-
+__END__
 
 =pod
 
@@ -60,7 +60,7 @@ Log::Dispatch::Base - Code shared by dispatch and output objects.
 
 =head1 VERSION
 
-version 2.32
+version 2.41
 
 =head1 SYNOPSIS
 
@@ -81,14 +81,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2013 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
