@@ -1,6 +1,6 @@
 package Log::Dispatch::File;
 {
-  $Log::Dispatch::File::VERSION = '2.32';
+  $Log::Dispatch::File::VERSION = '2.41';
 }
 
 use strict;
@@ -13,10 +13,12 @@ use base qw( Log::Dispatch::Output );
 use Params::Validate qw(validate SCALAR BOOLEAN);
 Params::Validate::validation_options( allow_extra => 1 );
 
+use Scalar::Util qw( openhandle );
+
 # Prevents death later on if IO::File can't export this constant.
 *O_APPEND = \&APPEND unless defined &O_APPEND;
 
-sub APPEND {0}
+sub APPEND { 0 }
 
 sub new {
     my $proto = shift;
@@ -27,16 +29,19 @@ sub new {
     my $self = bless {}, $class;
 
     $self->_basic_init(%p);
-    $self->_make_handle(%p);
+    $self->_make_handle;
 
     return $self;
 }
 
-sub _make_handle {
+sub _basic_init {
     my $self = shift;
 
+    $self->SUPER::_basic_init(@_);
+
     my %p = validate(
-        @_, {
+        @_,
+        {
             filename => { type => SCALAR },
             mode     => {
                 type    => SCALAR,
@@ -58,13 +63,19 @@ sub _make_handle {
                 type     => SCALAR,
                 optional => 1
             },
+            syswrite => {
+                type    => BOOLEAN,
+                default => 0
+            },
         }
     );
 
     $self->{filename}    = $p{filename};
+    $self->{binmode}     = $p{binmode};
+    $self->{autoflush}   = $p{autoflush};
     $self->{close}       = $p{close_after_write};
     $self->{permissions} = $p{permissions};
-    $self->{binmode}     = $p{binmode};
+    $self->{syswrite}    = $p{syswrite};
 
     if ( $self->{close} ) {
         $self->{mode} = '>>';
@@ -84,10 +95,12 @@ sub _make_handle {
         $self->{mode} = '>';
     }
 
-    $self->{autoflush} = $p{autoflush};
+}
 
-    $self->_open_file() unless $p{close_after_write};
+sub _make_handle {
+    my $self = shift;
 
+    $self->_open_file() unless $self->{close};
 }
 
 sub _open_file {
@@ -125,22 +138,25 @@ sub log_message {
     my $self = shift;
     my %p    = @_;
 
-    my $fh;
-
     if ( $self->{close} ) {
         $self->_open_file;
-        $fh = $self->{fh};
-        print $fh $p{message}
-            or die "Cannot write to '$self->{filename}': $!";
+    }
 
-        close $fh
-            or die "Cannot close '$self->{filename}': $!";
+    my $fh = $self->{fh};
+
+    if ( $self->{syswrite} ) {
+        defined syswrite( $fh, $p{message} )
+            or die "Cannot write to '$self->{filename}': $!";
     }
     else {
-        $fh = $self->{fh};
         print $fh $p{message}
             or die "Cannot write to '$self->{filename}': $!";
     }
+
+    if ( $self->{close} ) {
+        close $fh
+            or die "Cannot close '$self->{filename}': $!";
+    }
 }
 
 sub DESTROY {
@@ -148,7 +164,7 @@ sub DESTROY {
 
     if ( $self->{fh} ) {
         my $fh = $self->{fh};
-        close $fh;
+        close $fh if openhandle($fh);
     }
 }
 
@@ -156,7 +172,7 @@ sub DESTROY {
 
 # ABSTRACT: Object for logging to files
 
-
+__END__
 
 =pod
 
@@ -166,7 +182,7 @@ Log::Dispatch::File - Object for logging to files
 
 =head1 VERSION
 
-version 2.32
+version 2.41
 
 =head1 SYNOPSIS
 
@@ -220,13 +236,19 @@ A layer name to be passed to binmode, like ":encoding(UTF-8)" or ":raw".
 Whether or not the file should be closed after each write.  This
 defaults to false.
 
-If this is true, then the mode will aways be append, so that the file
-is not re-written for each new message.
+If this is true, then the mode will always be append, so that the file is not
+re-written for each new message.
 
 =item * autoflush ($)
 
 Whether or not the file should be autoflushed.  This defaults to true.
 
+=item * syswrite ($)
+
+Whether or not to perform the write using L<perlfunc/syswrite>(),
+as opposed to L<perlfunc/print>().  This defaults to false.
+The usual caveats and warnings as documented in L<perlfunc/syswrite> apply.
+
 =item * permissions ($)
 
 If the file does not already exist, the permissions that it should
@@ -254,14 +276,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2013 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
