@@ -1,6 +1,6 @@
 package Log::Dispatch::Null;
 {
-  $Log::Dispatch::Null::VERSION = '2.32';
+  $Log::Dispatch::Null::VERSION = '2.41';
 }
 
 use strict;
@@ -27,7 +27,7 @@ sub log_message { }
 
 # ABSTRACT: Object that accepts messages and does nothing
 
-
+__END__
 
 =pod
 
@@ -37,13 +37,14 @@ Log::Dispatch::Null - Object that accepts messages and does nothing
 
 =head1 VERSION
 
-version 2.32
+version 2.41
 
 =head1 SYNOPSIS
 
   use Log::Dispatch;
 
-  my $null = Log::Dispatch->new( outputs => [ ['Null'] ] );
+  my $null
+      = Log::Dispatch->new( outputs => [ [ 'Null', min_level => 'debug' ] ] );
 
   $null->emerg( "I've fallen and I can't get up" );
 
@@ -58,15 +59,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2013 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
-
